@@ -109,7 +109,7 @@ def is_method(x):
 
     return None
 
-is_containing_comp_end = lambda x: is_list_containing(x, 'comp.end')
+is_containing_comp_end = lambda x: is_list_containing(x, 'comp.end', False)
 is_containing_netc = lambda x: is_list_containing(x, 'comp_neg.etc', False)
 is_containing_petc = lambda x: is_list_containing(x, 'comp_pos.etc', False)
 is_etc_n_b4_inters = lambda x: is_bool(x, 'comp_neg.put_etc_before')
