@@ -72,7 +72,7 @@ def compute_correction_evaluated_at_func(
     dat = {}
     dat[pop_sex_age[0]] = []
     dat[pop_sex_age[1]] = []
-    dat['Problematic component'] = []
+    dat['Component'] = []
     dat[colname] = []
     for i in range(1, len(result_fix_issues)):
         problematic_sex_age = result_fix_issues[i]\
@@ -93,7 +93,7 @@ def compute_correction_evaluated_at_func(
         quant = func(comp_L_values, *args, **kwargs)
         dat[pop_sex_age[0]].append(p_sex)
         dat[pop_sex_age[1]].append(p_age)
-        dat['Problematic component'].append(p_comp)
+        dat['Component'].append(p_comp)
         dat[colname].append(quant)
 
     return pd.DataFrame(dat)
