@@ -838,6 +838,8 @@ class ProvPopTable(pd.DataFrame):
         comps_modified = []
         sexes = np.unique(self[self.__pop_sex])
         self_copy = None
+        method = return_goption_if_None('method', method)
+
         for sex in sexes:
             self_cp_sex =\
                 self.copy().loc[lambda df: df[self.__pop_sex] == sex]
@@ -926,7 +928,8 @@ class ProvPopTable(pd.DataFrame):
                 return self_copy
             result = ProvPopTableResultsWrapper(
                 orig_table = self, 
-                result_fix_issues = [self_copy] + comps_modified
+                result_fix_issues = [self_copy] + comps_modified,
+                method = method
             )
             return result
         else:
